@@ -54,8 +54,6 @@
 #include <glib/gi18n.h>
 #include <glib.h>
 
-#include <libgnome/gnome-macros.h>
-
 #include "anjuta-utils.h"
 #include "anjuta-marshal.h"
 #include "resources.h"
@@ -67,13 +65,13 @@
 #define FILE_INPUT_BUFFER_SIZE		1048576
 #ifndef __MAX_BAUD
 #  if defined(B460800)
-#    define __MAX_BAUX B460800
+#    define __MAX_BAUD B460800
 #  elif defined(B307200)
-#    define __MAX_BAUX B307200
+#    define __MAX_BAUD B307200
 #  elif defined(B256000)
-#    define __MAX_BAUX B256000
+#    define __MAX_BAUD B256000
 #  else
-#    define __MAX_BAUX B230400
+#    define __MAX_BAUD B230400
 #  endif
 #endif
 
@@ -267,7 +265,7 @@ anjuta_launcher_dispose (GObject *obj)
 		launcher->priv->busy = FALSE;
 		
 	}
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (obj));
+	G_OBJECT_CLASS (parent_class)->dispose (obj);
 }
 
 static void
@@ -280,7 +278,7 @@ anjuta_launcher_finalize (GObject *obj)
 	g_hash_table_destroy (launcher->priv->env);
 	
 	g_free (launcher->priv);
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (obj));
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 static void
@@ -425,7 +423,11 @@ anjuta_launcher_send_ptyin (AnjutaLauncher *launcher, const gchar * input_str)
 	gsize bytes_written;
 	GError *err = NULL;
 	
-	if (!input_str || strlen (input_str) == 0) return;
+	g_return_if_fail (launcher);
+	g_return_if_fail (input_str);
+	
+	if (strlen (input_str) == 0) 
+		return;
 
 	do
 	{	
@@ -619,7 +621,6 @@ anjuta_launcher_check_password_real (AnjutaLauncher *launcher,
 					g_free (line);
 					break;
 				case GTK_RESPONSE_CANCEL:
-					anjuta_launcher_send_ptyin (launcher, "<canceled>\n");
 					anjuta_launcher_reset (launcher);
 					break;
 				default:
@@ -1092,43 +1093,15 @@ anjuta_launcher_set_encoding (AnjutaLauncher *launcher, const gchar *charset)
 	  launcher->priv->encoding = NULL;		
 }
 
-/**
- * anjuta_launcher_set_env:
- * @launcher: a #AnjutaLancher object.
- * @name: Name of the environment variable to set
- * @value: Value of the environment variable to set
- * 
- * Set an environment variable for the forked process
- *
- */ 
-void
-anjuta_launcher_set_env (AnjutaLauncher *launcher,
-						 const gchar *name,
-						 const gchar *value)
-{
-	g_return_if_fail (launcher && ANJUTA_IS_LAUNCHER(launcher));
-	g_return_if_fail (name != NULL);
-	g_return_if_fail (value != NULL);
-	
-	g_hash_table_insert (launcher->priv->env,
-						 g_strdup(name),
-						 g_strdup(value));
-}
-
-static void
-anjuta_launcher_fork_setenv (const gchar* name, const gchar* value)
-{
-	setenv (name, value, TRUE);
-}
-
 static pid_t
-anjuta_launcher_fork (AnjutaLauncher *launcher, gchar *const args[])
+anjuta_launcher_fork (AnjutaLauncher *launcher, gchar *const args[], gchar *const envp[])
 {
 	char *working_dir;
 	int pty_master_fd, md;
 	int stdout_pipe[2], stderr_pipe[2];
 	pid_t child_pid;
 	struct termios termios_flags;
+	gchar * const *env;
 	
 	working_dir = g_get_current_dir ();
 	
@@ -1161,10 +1134,26 @@ anjuta_launcher_fork (AnjutaLauncher *launcher, gchar *const args[])
 			fcntl (stderr_pipe[1], F_SETFL, O_SYNC | md);
 		
 		/* Set up environment */
-		g_hash_table_foreach (launcher->priv->env,
-							  (GHFunc) anjuta_launcher_fork_setenv,
-							  NULL);
-		
+		if (envp != NULL)
+		{
+			GString *variable = g_string_new (NULL);
+			for (env = envp; *env != NULL; env++)
+			{
+				gchar *value = strchr (*env, '=');
+
+				if (value == NULL)
+				{
+					g_setenv (*env, NULL, TRUE);
+				}
+				else
+				{
+					g_string_truncate (variable, 0);
+					g_string_append_len (variable, *env, value - *env);
+					g_setenv (variable->str, value + 1, TRUE);
+				}
+			}
+		}
+	
 		execvp (args[0], args);
 		g_warning (_("Cannot execute command: \"%s\""), args[0]);
 		perror(_("execvp failed"));
@@ -1253,6 +1242,7 @@ anjuta_launcher_fork (AnjutaLauncher *launcher, gchar *const args[])
  * anjuta_launcher_execute_v:
  * @launcher: a #AnjutaLancher object.
  * @argv: Command args.
+ * @envp: Additional environment variable.
  * @callback: The callback for delivering output from the process.
  * @callback_data: Callback data for the above callback.
  * 
@@ -1263,6 +1253,7 @@ anjuta_launcher_fork (AnjutaLauncher *launcher, gchar *const args[])
  */
 gboolean
 anjuta_launcher_execute_v (AnjutaLauncher *launcher, gchar *const argv[],
+						   gchar *const envp[],
 						   AnjutaLauncherOutputCallback callback,
 						   gpointer callback_data)
 {
@@ -1281,7 +1272,7 @@ anjuta_launcher_execute_v (AnjutaLauncher *launcher, gchar *const argv[],
 	launcher->priv->callback_data = callback_data;
 	
 	/* On a fork error perform a cleanup and return */
-	if (anjuta_launcher_fork (launcher, argv) < 0)
+	if (anjuta_launcher_fork (launcher, argv, envp) < 0)
 	{
 		anjuta_launcher_initialize (launcher);
 		return FALSE;
@@ -1327,7 +1318,7 @@ anjuta_launcher_execute (AnjutaLauncher *launcher, const gchar *command_str,
 	}
 	*args_ptr = NULL;
 
-	ret = anjuta_launcher_execute_v (launcher, args, 
+	ret = anjuta_launcher_execute_v (launcher, args, NULL,
 		callback, callback_data);
 	g_free (args);
 	anjuta_util_glist_strings_free (args_list);
