@@ -392,7 +392,7 @@ devhelp_activate (AnjutaPlugin *plugin)
 
 	/* Add watches */
 	devhelp->editor_watch_id = 
-		anjuta_plugin_add_watch (plugin, "document_manager_current_editor",
+		anjuta_plugin_add_watch (plugin,  IANJUTA_DOCUMENT_MANAGER_CURRENT_DOCUMENT,
 								 value_added_current_editor,
 								 value_removed_current_editor,
 								 devhelp);
@@ -457,7 +457,7 @@ devhelp_finalize (GObject *obj)
 	/* Finalization codes here */
 	AnjutaDevhelp *plugin = ANJUTA_PLUGIN_DEVHELP (obj);
 	
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (obj));
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 static void
@@ -469,7 +469,7 @@ devhelp_dispose (GObject *obj)
 	// g_object_unref(G_OBJECT(devhelp->base));
 
 	/* Disposition codes */
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (obj));
+	G_OBJECT_CLASS (parent_class)->dispose (obj);
 }
 #endif
 
