@@ -33,6 +33,8 @@
 #include <libanjuta/interfaces/ianjuta-file.h>
 #include <libanjuta/interfaces/ianjuta-file-loader.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
+#include <libanjuta/interfaces/ianjuta-file-manager.h>
+#include <libanjuta/interfaces/ianjuta-project-manager.h>
 #include <libanjuta/interfaces/ianjuta-wizard.h>
 
 #include "plugin.h"
@@ -257,7 +259,9 @@ open_with_dialog (AnjutaFileLoaderPlugin *plugin, const gchar *uri,
 												 NULL);
 			if (docman)
 			{
-				ianjuta_file_open (IANJUTA_FILE (docman), uri, NULL);
+				GFile* file = g_file_new_for_uri (uri);
+				ianjuta_file_open (IANJUTA_FILE (docman), file, NULL);
+				g_object_unref (file);
 			}
 			else
 			{
@@ -283,8 +287,10 @@ open_with_dialog (AnjutaFileLoaderPlugin *plugin, const gchar *uri,
 															location);
 				if (loaded_plugin)
 				{
-					ianjuta_file_open (IANJUTA_FILE (loaded_plugin), uri, NULL);
+					GFile* file = g_file_new_for_uri (uri);
+					ianjuta_file_open (IANJUTA_FILE (loaded_plugin), file, NULL);
 					set_recent_file (plugin, uri, mime_type);
+					g_object_unref (file);
 				}
 				else
 				{
@@ -354,6 +360,7 @@ open_file (AnjutaFileLoaderPlugin *plugin, const gchar *uri)
 {
 	GnomeVFSURI *vfs_uri;	
 	gchar *dirname;
+	GFile* file;
 	
 	vfs_uri = gnome_vfs_uri_new (uri);
 	dirname = gnome_vfs_uri_extract_dirname (vfs_uri);
@@ -361,10 +368,14 @@ open_file (AnjutaFileLoaderPlugin *plugin, const gchar *uri)
 	chdir (dirname);
 	g_free (dirname);
 	
+	file = g_file_new_for_uri (uri);
+	
 	/* FIXME: We have to manage the error to know if we have to remove the recent file
 	 */
 	ianjuta_file_loader_load (IANJUTA_FILE_LOADER (plugin),
-							  uri, FALSE, NULL);
+							  file, FALSE, NULL);
+	
+	g_object_unref (file);
 }
 
 typedef struct
@@ -535,6 +546,9 @@ create_file_open_dialog_gui(GtkWindow* parent, AnjutaFileLoaderPlugin* plugin)
 									NULL);
 	gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER(dialog), TRUE);
 	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (dialog), FALSE);
+	gtk_dialog_set_default_response (GTK_DIALOG(dialog), GTK_RESPONSE_ACCEPT);
+	gtk_window_set_destroy_with_parent (GTK_WINDOW(dialog), TRUE);
+	
 	setup_file_filters (GTK_FILE_CHOOSER (dialog));
 	
 	g_signal_connect(G_OBJECT(dialog), "response", 
@@ -721,8 +735,10 @@ open_file_with (AnjutaFileLoaderPlugin *plugin, GtkMenuItem *menuitem,
 														location);
 			if (loaded_plugin)
 			{
-				ianjuta_file_open (IANJUTA_FILE (loaded_plugin), uri, NULL);
+				GFile* file = g_file_new_for_uri (uri);
+				ianjuta_file_open (IANJUTA_FILE (loaded_plugin), file, NULL);
 				set_recent_file (plugin, uri, mime_type);
+				g_object_unref (file);
 			}
 			else
 			{
@@ -922,16 +938,17 @@ create_open_with_submenu (AnjutaFileLoaderPlugin *plugin, GtkWidget *parentmenu,
 }
 						  
 static void
-value_added_fm_current_uri (AnjutaPlugin *plugin, const char *name,
+value_added_fm_current_file (AnjutaPlugin *plugin, const char *name,
 							const GValue *value, gpointer data)
 {
 	AnjutaUI *ui;
-	const gchar *uri;
+	gchar *uri;
 	AnjutaFileLoaderPlugin *fl_plugin;
 	GtkAction *action;
 	GtkWidget *parentmenu;
+	GFile* file = G_FILE (g_value_get_object (value));
 	
-	uri = g_value_get_string (value);
+	uri = g_file_get_uri (file);
 	g_return_if_fail (name != NULL);
 
 	fl_plugin = ANJUTA_PLUGIN_FILE_LOADER (plugin);
@@ -954,10 +971,12 @@ value_added_fm_current_uri (AnjutaPlugin *plugin, const char *name,
 	if (!create_open_with_submenu (fl_plugin, parentmenu, uri,
 								   G_CALLBACK (fm_open_with), plugin))
 		g_object_set (G_OBJECT (action), "sensitive", FALSE, NULL);
+	
+	g_free (uri);
 }
 
 static void
-value_removed_fm_current_uri (AnjutaPlugin *plugin,
+value_removed_fm_current_file (AnjutaPlugin *plugin,
 							  const char *name, gpointer data)
 {
 	AnjutaUI *ui;
@@ -1040,7 +1059,9 @@ value_removed_pm_current_uri (AnjutaPlugin *plugin,
 static void
 dnd_dropped (const gchar *uri, gpointer plugin)
 {
-	ianjuta_file_loader_load (IANJUTA_FILE_LOADER (plugin), uri, FALSE, NULL);
+	GFile* file = g_file_new_for_uri (uri);
+	ianjuta_file_loader_load (IANJUTA_FILE_LOADER (plugin), file, FALSE, NULL);
+	g_object_unref (file);
 }
 
 static void
@@ -1082,7 +1103,7 @@ on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase,
 				if (strchr (filename, '#'))
 					*(strchr (filename, '#')) = '\0';
 				
-				label = g_strconcat ("Loaded: ", filename, NULL);
+				label = g_strconcat (_("Loaded:"), " ", filename, NULL);
 				
 				if (i == 0 && mime_type &&
 					strcmp (mime_type, "application/x-anjuta") == 0)
@@ -1100,9 +1121,11 @@ on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase,
 						  strcmp (mime_type, "application/x-anjuta") != 0))
 				{
 					/* Then rest of the files */
+					GFile* file = g_file_new_for_uri (uri);
 					ianjuta_file_loader_load (IANJUTA_FILE_LOADER (plugin),
-											  uri, FALSE, NULL);
+											  file, FALSE, NULL);
 					anjuta_status_progress_tick (status, NULL, label);
+					g_object_unref (file);
 				}
 				g_free (filename);
 				g_free (label);
@@ -1125,6 +1148,7 @@ setup_recent_chooser_menu (GtkRecentChooser* recent_menu, AnjutaFileLoaderPlugin
 
 	gtk_recent_chooser_set_local_only (GTK_RECENT_CHOOSER (recent_menu), TRUE);
 	gtk_recent_chooser_set_show_icons (GTK_RECENT_CHOOSER (recent_menu), TRUE);
+	gtk_recent_chooser_set_show_tips (GTK_RECENT_CHOOSER (recent_menu), TRUE);
 	gtk_recent_chooser_set_sort_type (GTK_RECENT_CHOOSER (recent_menu), GTK_RECENT_SORT_MRU);
 	gtk_recent_chooser_set_limit (GTK_RECENT_CHOOSER (recent_menu), 20);
 
@@ -1226,11 +1250,11 @@ activate_plugin (AnjutaPlugin *plugin)
 	
 	/* Add watches */
 	loader_plugin->fm_watch_id = 
-		anjuta_plugin_add_watch (plugin, "file_manager_current_uri",
-								 value_added_fm_current_uri,
-								 value_removed_fm_current_uri, NULL);
+		anjuta_plugin_add_watch (plugin, IANJUTA_FILE_MANAGER_SELECTED_FILE,
+								 value_added_fm_current_file,
+								 value_removed_fm_current_file, NULL);
 	loader_plugin->pm_watch_id = 
-		anjuta_plugin_add_watch (plugin, "project_manager_current_uri",
+		anjuta_plugin_add_watch (plugin, IANJUTA_PROJECT_MANAGER_CURRENT_URI,
 								 value_added_pm_current_uri,
 								 value_removed_pm_current_uri, NULL);
 	
@@ -1305,7 +1329,7 @@ anjuta_file_loader_plugin_class_init (GObjectClass *klass)
 }
 
 static GObject*
-iloader_load (IAnjutaFileLoader *loader, const gchar *uri,
+iloader_load (IAnjutaFileLoader *loader, GFile* file,
 			  gboolean read_only, GError **err)
 {
 	gchar *mime_type;
@@ -1315,6 +1339,7 @@ iloader_load (IAnjutaFileLoader *loader, const gchar *uri,
 	AnjutaPluginManager *plugin_manager;
 	GList *plugin_descs = NULL;
 	GObject *plugin = NULL;	
+	gchar* uri = g_file_get_uri (file);
 	
 	g_return_val_if_fail (uri != NULL, NULL);
 	vfs_uri = gnome_vfs_uri_new (uri);
@@ -1386,7 +1411,9 @@ iloader_load (IAnjutaFileLoader *loader, const gchar *uri,
 		launch_in_default_application (ANJUTA_PLUGIN_FILE_LOADER (loader), mime_type, uri);
 	}
 	if (plugin)
-		ianjuta_file_open (IANJUTA_FILE(plugin), uri, NULL);
+	{
+		ianjuta_file_open (IANJUTA_FILE(plugin), file, NULL);
+	}
 	
 	set_recent_file (ANJUTA_PLUGIN_FILE_LOADER (loader), new_uri, mime_type);
 	
@@ -1394,8 +1421,9 @@ iloader_load (IAnjutaFileLoader *loader, const gchar *uri,
 		g_list_free (plugin_descs);
 	g_free (mime_type);
 	g_free (new_uri);
+	g_free (uri);
 	anjuta_status_busy_pop (status);
-
+		
 	return plugin;
 }
 
