@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #ifndef _UTILITIES_H_
 #define _UTILITIES_H_
@@ -260,12 +260,6 @@ gboolean is_file_in_dir(const gchar *file, const gchar *dir);
 
 GList *glist_path_dedup(GList *list);
 
-/* Check which gnome-terminal is installed
- Returns: 0 -- No gnome-terminal
- Returns: 1 -- Gnome1 gnome-terminal
- Returns: 2 -- Gnome2 gnome-terminal */
-gint gdb_util_check_gnome_terminal (void);
-
 /* String integer mapping utility functions */
 typedef struct _StringMap
 {
