@@ -187,7 +187,7 @@ about_box_new ()
 		_("Integrated Development Environment"));
 	gtk_about_dialog_set_license(GTK_ABOUT_DIALOG(dialog), 
 		NULL);
-	gtk_about_dialog_set_website(GTK_ABOUT_DIALOG(dialog), "www.anjuta.org");
+	gtk_about_dialog_set_website(GTK_ABOUT_DIALOG(dialog), "http://www.anjuta.org");
 	gtk_about_dialog_set_logo(GTK_ABOUT_DIALOG(dialog), pix);
 	
 	gtk_about_dialog_set_authors(GTK_ABOUT_DIALOG(dialog), authors);
@@ -212,10 +212,10 @@ on_about_plugin_activate (GtkMenuItem *item, AnjutaPluginDescription *desc)
 	GdkPixbuf *pix = NULL;
 	GtkWidget *dialog;
 	
-	anjuta_plugin_description_get_string (desc, "Anjuta Plugin",
-										  "Name", &name);
-	anjuta_plugin_description_get_string (desc, "Anjuta Plugin",
-										  "Description", &d);
+	anjuta_plugin_description_get_locale_string (desc, "Anjuta Plugin",
+												 "Name", &name);
+	anjuta_plugin_description_get_locale_string (desc, "Anjuta Plugin",
+												 "Description", &d);
 	anjuta_plugin_description_get_string (desc, "Anjuta Plugin",
 										  "Icon", &icon);
 	anjuta_plugin_description_get_string (desc, "Anjuta Plugin",
@@ -230,8 +230,6 @@ on_about_plugin_activate (GtkMenuItem *item, AnjutaPluginDescription *desc)
 	{
 		authors_v = g_strsplit(authors, ",", -1);
 	}
-	/*dialog = gnome_about_new (name, VERSION, _("Anjuta plugin"), d,
-							  authors_v, NULL, NULL, pix);*/
 	dialog = gtk_about_dialog_new();
 	gtk_about_dialog_set_name(GTK_ABOUT_DIALOG(dialog), name);
 	gtk_about_dialog_set_version(GTK_ABOUT_DIALOG(dialog), VERSION);
@@ -274,8 +272,8 @@ about_create_plugins_submenu (AnjutaShell *shell, GtkWidget *menuitem)
 		gchar *label;
 		GtkWidget *item;
 		AnjutaPluginDescription *desc = node->data;
-		if (anjuta_plugin_description_get_string (desc, "Anjuta Plugin",
-												  "Name", &label))
+		if (anjuta_plugin_description_get_locale_string (desc, "Anjuta Plugin",
+														 "Name", &label))
 		{
 			gchar *authors;
 			if (anjuta_plugin_description_get_string (desc, "Anjuta Plugin",
